@@ -114,6 +114,7 @@ const GList         *gda_connection_get_errors (GdaConnection *cnc);
 
 typedef enum {
 	GDA_CONNECTION_FEATURE_AGGREGATES,
+	GDA_CONNECTION_FEATURE_BLOBS,
 	GDA_CONNECTION_FEATURE_INDEXES,
 	GDA_CONNECTION_FEATURE_INHERITANCE,
 	GDA_CONNECTION_FEATURE_NAMESPACES,
@@ -125,8 +126,7 @@ typedef enum {
 	GDA_CONNECTION_FEATURE_UPDATABLE_CURSOR,
 	GDA_CONNECTION_FEATURE_USERS,
 	GDA_CONNECTION_FEATURE_VIEWS,
-	GDA_CONNECTION_FEATURE_XML_QUERIES,
-	GDA_CONNECTION_FEATURE_BLOBS
+	GDA_CONNECTION_FEATURE_XML_QUERIES
 } GdaConnectionFeature;
 
 gboolean             gda_connection_supports (GdaConnection *cnc, GdaConnectionFeature feature);
